@@ -17,7 +17,7 @@ class instrument:
     def __init__(self,port):
         rm = pyvisa.ResourceManager()
         current_port = port.name
-        self.MaiTai = rm.open_resource(f'ASRL/{current_port}::INSTR')
+        self.MaiTai = rm.open_resource(f'ASRL/dev/{current_port}::INSTR')
         self.MaiTai.baud_rate = 115200
 
     def Shutter(self,val=0):
