@@ -17,6 +17,7 @@ class Instrument:
 class InstrumentWrapper(param.Parameterized):
     instrument_selected = param.ObjectSelector()
     button = pn.widgets.Button(name='Reload devices', button_type='primary')
+    button2 = pn.widgets.Button(name="Initialize instrument", button_type='primary')
 
     def __init__(self, modules, name):
         super().__init__()
@@ -27,10 +28,10 @@ class InstrumentWrapper(param.Parameterized):
         self.hwids = [self.modules[i]["hwid"] for i in self.modules]
         self.reload_devices()
         self.button.on_click(self.reload_devices)
+        self.button2.on_click(self.initialize)
         if "software_software" in self.devices.keys():
             self.instrument_selected = "software_software"
-        elif len(self.devices.keys()) == 1:
-            self.instrument_selected = list(self.devices.keys())[0]  # use only available option
+            self.load_device()
 
     def reload_devices(self, event=None, debug=False):
         ports = find_ports()
@@ -53,7 +54,11 @@ class InstrumentWrapper(param.Parameterized):
                                                   "serial_number": port.serial_number, "module": module, "port": port}
         self.param["instrument_selected"].objects = self.devices.keys()
 
-    @param.depends("instrument_selected", watch=True)
+    def initialize(self, event=None):
+        if self.instrument_selected == None:
+            self.instrument_selected = list(self.devices.keys())[0]
+        self.load_device()
+
     def load_device(self):
         module = self.devices[self.instrument_selected]["module"]
         self.instrument = self.modules[module]["module"].instrument(
@@ -61,7 +66,7 @@ class InstrumentWrapper(param.Parameterized):
 
     def view(self):
 
-        return pn.Column(self.param, self.button)
+        return pn.Column(self.param, self.button,self.button2)
 
     def serve(self):
         self.view().show(port=5006)
