@@ -22,7 +22,7 @@ class instrument:
         self.rotator.home()
 
     def move_abs(self, value):
-        self.rotator.move_abs(value)
+        self.rotator.moveabs(value)
 
     def move_rel(self, val_dif):
-        self.rotator.move_rel(val_dif)
+        self.rotator.moverel(val_dif)
